==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/zh-TW/mail.php <==
<?php

return array(
    'a_user_canceled' => '使用者已取消項目申請',
    'a_user_requested' => '使用者已申請項目',
    'accessory_name' => '配件名稱：',
    'additional_notes' => '備註：',
    'admin_has_created' => '管理員已在 :web 為您新增帳號',
    'asset' => '資產：',
    'asset_name' => '資產名稱：',
    'asset_requested' => '申請資產',
    'asset_tag' => '資產標籤：',
    'assigned_to' => '分配給',
    'best_regards' => 'Best regards,',
    'canceled' => '取消：',
    'checkin_date' => '繳回日期：',
    'checkout_date' => '借出日期：',
    'click_to_confirm' => '請點擊鏈結啟用您 :web 的帳戶：',
    'click_on_the_link_accessory' => '請點擊鏈結確認您已收到配件。',
    'click_on_the_link_asset' => '請點擊鏈結確認您已收到資產。',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => '目前數量',
    'Days' => '日',
    'days' => '日',
    'expecting_checkin_date' => '預計歸還日期：',
    'expires' => '過期',
    'Expiring_Assets_Report' => '過期資產報告',
    'Expiring_Licenses_Report' => '過期授權報告',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => '我同意使用條款，並且已經收到物品。',
    'item' => '項目：',
    'Item_Request_Canceled' => '已取消申請物品',
    'Item_Requested' => '已申請物品',
    'link_to_update_password' => '請點擊以下鏈結以更新 :web 的密碼：',
    'login_first_admin' => '使用以下憑證登入新安裝的 Snipe-IT：',
    'login' => '登入',
    'Low_Inventory_Report' => '低庫存報告',
    'min_QTY' => '最小數量',
    'name' => '名字',
    'new_item_checked' => '一項新物品已分配至您的名下，詳細資訊如下。',
    'password' => '密碼',
    'password_reset' => '密碼重設',

    'read_the_terms' => '請閱讀以下使用條款。',
    'read_the_terms_and_click' => '請閱讀使用條款，點擊底下鏈結確認您已閱讀並同意使用條款，並已收到資產。',
    'requested' => '已申請',
    'reset_link' => '您的密碼重設連結',
    'reset_password' => '請按一下此處重置您的密碼︰',
    'serial' => '序號',
    'supplier' => '供應商',
    'tag' => '標籤',
    'test_email' => 'Snipe-IT 測試電子郵件',
    'test_mail_text' => '這是一封 Snipe-IT 資產管理系統的測試電子郵件，如果您收到，表示郵件通知正常運作 :)',
    'the_following_item' => '以下項目已繳回：',
    'low_inventory_alert' => '有 :count 種物品已經低於或者接近最小庫存。|有 :count 種物品已經低於或者接近最小庫存。',
    'assets_warrantee_alert' => '有 :count 項資產的保固將在 :threshold 天後到期。|有 :count 項資產的保固將在 :threshold 天後到期。',
    'license_expiring_alert' => '有 :count 個授權將在 :threshold 天後到期。|有 :count 個授權將在 :threshold 天後到期。',
    'to_reset' => '要重設 :web 的密碼，請完成此表單：',
    'type' => '類型',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => '使用者',
    'username' => '使用者名稱',
    'welcome' => '歡迎您 :name',
    'welcome_to' => '歡迎來到 :web！',
    'your_credentials' => '您的 Snipe-IT 憑證',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => '查看您的資產'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/zh-TW/mail.php <==
<?php

return [
    'a_user_canceled' => '使用者已取消項目申請',
    'a_user_requested' => '使用者已申請項目',
    'accessory_name' => '配件名稱：',
    'additional_notes' => '備註：',
    'admin_has_created' => '管理員已在 :web 為您新增帳號',
    'asset' => '資產：',
    'asset_name' => '資產名稱：',
    'asset_requested' => '申請資產',
    'asset_tag' => '資產標籤',
    'assigned_to' => '分配給',
    'best_regards' => 'Best regards,',
    'canceled' => '取消：',
    'checkin_date' => '繳回日期：',
    'checkout_date' => '借出日期：',
    'click_to_confirm' => '請點擊鏈結啟用您 :web 的帳戶：',
    'click_on_the_link_accessory' => '請點擊鏈結確認您已收到配件。',
    'click_on_the_link_asset' => '請點擊鏈結確認您已收到資產。',
    'Confirm_Asset_Checkin' => '確認資產繳回',
    'Confirm_Accessory_Checkin' => '確認配件繳回',
    'Confirm_accessory_delivery' => '確認交付配件',
    'Confirm_license_delivery' => '確認交付授權',
    'Confirm_asset_delivery' => '確認交付資產',
    'Confirm_consumable_delivery' => '確認交付耗材',
    'current_QTY' => '目前數量',
    'Days' => '日',
    'days' => '日',
    'expecting_checkin_date' => '預計歸還日期：',
    'expires' => '過期',
    'Expiring_Assets_Report' => '過期資產報告',
    'Expiring_Licenses_Report' => '過期授權報告',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => '我同意使用條款，並且已經收到物品。',
    'item' => '項目：',
    'Item_Request_Canceled' => '已取消申請物品',
    'Item_Requested' => '已申請物品',
    'link_to_update_password' => '請點擊以下鏈結以更新 :web 的密碼：',
    'login_first_admin' => '使用以下憑證登入新安裝的 Snipe-IT：',
    'login' => '登入',
    'Low_Inventory_Report' => '低庫存報告',
    'min_QTY' => '最小數量',
    'name' => '名字',
    'new_item_checked' => '一項新物品已分配至您的名下，詳細資訊如下。',
    'password' => '密碼',
    'password_reset' => '密碼重設',

    'read_the_terms' => '請閱讀以下使用條款。',
    'read_the_terms_and_click' => '請閱讀使用條款，點擊底下鏈結確認您已閱讀並同意使用條款，並已收到資產。',
    'requested' => '已申請',
    'reset_link' => '您的密碼重設連結',
    'reset_password' => '請按一下此處重置您的密碼︰',
    'serial' => '序號',
    'supplier' => '供應商',
    'tag' => '標籤',
    'test_email' => 'Snipe-IT 測試電子郵件',
    'test_mail_text' => '這是一封 Snipe-IT 資產管理系統的測試電子郵件，如果您收到，表示郵件通知正常運作 :)',
    'the_following_item' => '以下項目已繳回：',
    'low_inventory_alert' => '有 :count 種物品已經低於或者接近最小庫存。|有 :count 種物品已經低於或者接近最小庫存。',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => '有 :count 個授權將在 :threshold 天後到期。|有 :count 個授權將在 :threshold 天後到期。',
    'to_reset' => '要重設 :web 的密碼，請完成此表單：',
    'type' => '類型',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => '使用者',
    'username' => '使用者名稱',
    'welcome' => '歡迎您 :name',
    'welcome_to' => '歡迎來到 :web！',
    'your_credentials' => '您的 Snipe-IT 憑證',
    'Accessory_Checkin_Notification' => '配件繳回',
    'Asset_Checkin_Notification' => '資產繳回',
    'License_Checkin_Notification' => '授權繳回',
    'Expected_Checkin_Report' => '預計資產繳回報告',
    'Expected_Checkin_Notification' => '提醒: :name 接近繳回最後期限',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => '查看您的資產',
];
